@@ -1,4 +1,4 @@
-package DataSplitValidateHashTest1;
+package DataSplitValidateHashTest2;
 
 use strict;
 use warnings;
@@ -7,10 +7,7 @@ use Test::More ();
 
 use parent 'Test::Data::Split::Backend::ValidateHash';
 
-my %hash =
-(
-);
-
+my %hash = ();
 
 sub get_hash
 {
@@ -19,20 +16,20 @@ sub get_hash
 
 sub run_id
 {
-    my ($self, $id) = @_;
+    my ( $self, $id ) = @_;
 
     my $data = $self->lookup_data($id);
 
-    Test::More::is ($data->{a} + $data->{b}, $data->{result}, "Testing $id.");
+    Test::More::is( $data->{a} + $data->{b}, $data->{result}, "Testing $id." );
 }
 
 sub validate_and_transform
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $data = $args->{data};
 
-    if ($data =~ /Just/)
+    if ( $data =~ /Just/ )
     {
         die "The data contains the word 'Just'. It is invalid.";
     }
